==> qtjambi-qt3drender-5.15.3-sources.jar: io/qt/qt3d/render/QRenderCaptureReply.java <==
package io.qt.qt3d.render;


/**
 * <p>Receives the result of render capture request</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html">Qt3DRender::QRenderCaptureReply</a></p>
 */
public final class QRenderCaptureReply extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderCaptureReply.class);
    

    /**
     * @deprecated Use completed instead
     */
    @Deprecated
    public final Signal1<@io.qt.QtPrimitiveType Boolean> completeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#complete-prop">Qt3DRender::QRenderCaptureReply::completed()</a></p>
     */
    @io.qt.QtPropertyNotify(name="complete")
    public final Signal0 completed = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#captureId-prop">Qt3DRender::QRenderCaptureReply::captureId()const</a></p>
     */
    @io.qt.QtPropertyReader(name="captureId")
    @io.qt.QtPropertyConstant
    @Deprecated
    @io.qt.QtUninvokable
    public final int captureId(){
        return captureId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native int captureId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#image-prop">Qt3DRender::QRenderCaptureReply::image()const</a></p>
     */
    @io.qt.QtPropertyReader(name="image")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.gui.QImage image(){
        return image_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QImage image_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#complete-prop">Qt3DRender::QRenderCaptureReply::isComplete()const</a></p>
     */
    @io.qt.QtPropertyReader(name="complete")
    @io.qt.QtUninvokable
    public final boolean isComplete(){
        return isComplete_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isComplete_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#saveImage">Qt3DRender::QRenderCaptureReply::saveImage(QString)const</a></p>
     */
    public final boolean saveImage(java.lang.String fileName){
        return saveImage_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), fileName);
    }
    
    private native boolean saveImage_native_cref_QString_constfct(long __this__nativeId, java.lang.String fileName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply-obsolete.html#saveToFile">Qt3DRender::QRenderCaptureReply::saveToFile(QString)const</a></p>
     * 
     * @deprecated Use {@link io.qt.qt3d.render.QRenderCaptureReply#saveImage(java.lang.String)} instead
     */
    @Deprecated
    public final void saveToFile(java.lang.String fileName){
        saveToFile_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), fileName);
    }
    
    @Deprecated
    private native void saveToFile_native_cref_QString_constfct(long __this__nativeId, java.lang.String fileName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderCaptureReply(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QRenderCaptureReply.java <==
package io.qt.qt3d.render;


/**
 * <p>Receives the result of render capture request</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html">Qt3DRender::QRenderCaptureReply</a></p>
 */
public final class QRenderCaptureReply extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderCaptureReply.class);
    

    /**
     * @deprecated Use completed instead
     */
    @Deprecated
    public final Signal1<@io.qt.QtPrimitiveType Boolean> completeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#complete-prop">Qt3DRender::QRenderCaptureReply::completed()</a></p>
     */
    @io.qt.QtPropertyNotify(name="complete")
    public final Signal0 completed = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#captureId-prop">Qt3DRender::QRenderCaptureReply::captureId()const</a></p>
     */
    @io.qt.QtPropertyReader(name="captureId")
    @io.qt.QtPropertyConstant
    @Deprecated
    @io.qt.QtUninvokable
    public final int captureId(){
        return captureId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native int captureId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#image-prop">Qt3DRender::QRenderCaptureReply::image()const</a></p>
     */
    @io.qt.QtPropertyReader(name="image")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.gui.QImage image(){
        return image_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QImage image_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#complete-prop">Qt3DRender::QRenderCaptureReply::isComplete()const</a></p>
     */
    @io.qt.QtPropertyReader(name="complete")
    @io.qt.QtUninvokable
    public final boolean isComplete(){
        return isComplete_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isComplete_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply.html#saveImage">Qt3DRender::QRenderCaptureReply::saveImage(QString)const</a></p>
     */
    public final boolean saveImage(java.lang.String fileName){
        return saveImage_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), fileName);
    }
    
    private native boolean saveImage_native_cref_QString_constfct(long __this__nativeId, java.lang.String fileName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendercapturereply-obsolete.html#saveToFile">Qt3DRender::QRenderCaptureReply::saveToFile(QString)const</a></p>
     * 
     * @deprecated Use {@link io.qt.qt3d.render.QRenderCaptureReply#saveImage(java.lang.String)} instead
     */
    @Deprecated
    public final void saveToFile(java.lang.String fileName){
        saveToFile_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), fileName);
    }
    
    @Deprecated
    private native void saveToFile_native_cref_QString_constfct(long __this__nativeId, java.lang.String fileName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderCaptureReply(QPrivateConstructor p) { super(p); } 
    
}
